@@ -910,7 +910,7 @@ sft_popup_rename_folder_response (GtkWidget *dialog, int response, SunOneFolderT
 	GList *l;
 	guint errcode = SUNONE_ERROR_CANNOT_MODIFY_LINKED_OBJECTS;
 	char *physical_uri, *calid, *type, *p;
-	const char *display_name;
+	const char *display_name = NULL;
 
 	g_return_if_fail (SUNONE_IS_FOLDER_TREE (tree));
 
