@@ -10,7 +10,12 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
+#include <glib/gi18n.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-moniker-util.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -715,7 +720,7 @@ sunone_invitation_list_model_set_value (SunOneInvitationListModel *model, int co
 		g_free (key);
 		if (wcap)
 			cal_backend_wcap_events_update_objects (E_CAL_BACKEND_SYNC (wcap), NULL,
-					icalcomponent_as_ical_string (clonecomp), CALOBJ_MOD_ALL, NULL);
+					icalcomponent_as_ical_string (clonecomp), CALOBJ_MOD_ALL, NULL, NULL);
 		icalcomponent_free (clonecomp);
 	}
 }
